@@ -165,6 +165,8 @@ extern "C" {
  * Bindings
  * ===================
  * - Python: https://gitlab.freedesktop.org/libevdev/python-libevdev
+ * - Haskell: http://hackage.haskell.org/package/evdev
+ * - Rust: https://crates.io/crates/evdev-rs
  *
  * Reporting bugs
  * ==============
@@ -1386,6 +1388,16 @@ int libevdev_has_property(const struct libevdev *dev, unsigned int prop);
  */
 int libevdev_enable_property(struct libevdev *dev, unsigned int prop);
 
+/**
+ * @ingroup kernel
+ *
+ * @param dev The evdev device
+ * @param prop The input property to disable, one of INPUT_PROP_...
+ *
+ * @return 0 on success or -1 on failure
+ */
+int libevdev_disable_property(struct libevdev *dev, unsigned int prop);
+
 /**
  * @ingroup bits
  *
@@ -1703,9 +1715,9 @@ int libevdev_get_current_slot(const struct libevdev *dev);
  *
  * @param dev The evdev device, already initialized with libevdev_set_fd()
  * @param code One of ABS_X, ABS_Y, ...
- * @param min The new minimum for this axis
+ * @param val The new minimum for this axis
  */
-void libevdev_set_abs_minimum(struct libevdev *dev, unsigned int code, int min);
+void libevdev_set_abs_minimum(struct libevdev *dev, unsigned int code, int val);
 
 /**
  * @ingroup kernel
@@ -1716,9 +1728,9 @@ void libevdev_set_abs_minimum(struct libevdev *dev, unsigned int code, int min);
  *
  * @param dev The evdev device, already initialized with libevdev_set_fd()
  * @param code One of ABS_X, ABS_Y, ...
- * @param max The new maxium for this axis
+ * @param val The new maxium for this axis
  */
-void libevdev_set_abs_maximum(struct libevdev *dev, unsigned int code, int max);
+void libevdev_set_abs_maximum(struct libevdev *dev, unsigned int code, int val);
 
 /**
  * @ingroup kernel
@@ -1729,9 +1741,9 @@ void libevdev_set_abs_maximum(struct libevdev *dev, unsigned int code, int max);
  *
  * @param dev The evdev device, already initialized with libevdev_set_fd()
  * @param code One of ABS_X, ABS_Y, ...
- * @param fuzz The new fuzz for this axis
+ * @param val The new fuzz for this axis
  */
-void libevdev_set_abs_fuzz(struct libevdev *dev, unsigned int code, int fuzz);
+void libevdev_set_abs_fuzz(struct libevdev *dev, unsigned int code, int val);
 
 /**
  * @ingroup kernel
@@ -1742,9 +1754,9 @@ void libevdev_set_abs_fuzz(struct libevdev *dev, unsigned int code, int fuzz);
  *
  * @param dev The evdev device, already initialized with libevdev_set_fd()
  * @param code One of ABS_X, ABS_Y, ...
- * @param flat The new flat for this axis
+ * @param val The new flat for this axis
  */
-void libevdev_set_abs_flat(struct libevdev *dev, unsigned int code, int flat);
+void libevdev_set_abs_flat(struct libevdev *dev, unsigned int code, int val);
 
 /**
  * @ingroup kernel
@@ -1755,9 +1767,9 @@ void libevdev_set_abs_flat(struct libevdev *dev, unsigned int code, int flat);
  *
  * @param dev The evdev device, already initialized with libevdev_set_fd()
  * @param code One of ABS_X, ABS_Y, ...
- * @param resolution The new axis resolution
+ * @param val The new axis resolution
  */
-void libevdev_set_abs_resolution(struct libevdev *dev, unsigned int code, int resolution);
+void libevdev_set_abs_resolution(struct libevdev *dev, unsigned int code, int val);
 
 /**
  * @ingroup kernel
